function numFr13 = countFr13(type, startDayFr13, varargin)
    % This function counts the occurrence of Friday the 13th for one of the
    % following valid types:
    % CCCL, CCLC, CLCC, LCCC, CCCC
    % and given the day of the week that Jan 13 of the first of the four
    % years falls under.
    
    % Days of the week mapping:
    % 0 -- Sunday
    % 1 -- Monday
    % 2 -- Tuesday
    % 3 -- Wednesday
    % 4 -- Thursday
    % 5 -- Friday
    % 6 -- Saturday
    
    % Please note that the CCCC case is possible because years like
    % 1900 is NOT a leap year.
    
    % Varargin if we are in an extended mode, and the first argument is the
    % start month (for arbitrary four year windows).
    
    if ~isempty(varargin)
        startMonth = varargin{1};
        daysVector = getCalendarFourYearsExtended(type, startMonth);
    else
        daysVector = getCalendarFourYears(type);
    end
    
    numFr13 = 0;
    if startDayFr13 == 5
        numFr13 = 1; 
    end
    
    % Please note: we don't need the number of days of the December of the
    % fourth year.
    oldDayOfTheWeek = startDayFr13;
    for k = 1:length(daysVector)-1
        curMonthDays = daysVector(k);
        newDayOfTheWeek = getDaysAdvanced(curMonthDays, oldDayOfTheWeek);
        
        if newDayOfTheWeek == 5
            % We got a Fr13!
            numFr13 = numFr13 + 1;
        end
        
        oldDayOfTheWeek = newDayOfTheWeek;
    end
end