function daysVector = getCalendarFourYears(type)
    % This function returns the vector of days in the 48 months of a four
    % year calendar span, depending on the span type.  For the Gregorian
    % Calendar, five types are possible.  We denote C as a common
    % (non-leap) year and L as a leap year.
    
    % CCCL, CCLC, CLCC, LCCC, CCCC
    
    % Please note that the last CCCC case is possible because years like
    % 1900 is NOT a leap year.
    
    commonYearVec = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    leapYearVec = commonYearVec;
    leapYearVec(2) = 29;
    
    switch type
        case 'CCCL'
            daysVector = [commonYearVec, commonYearVec, commonYearVec, leapYearVec];
        case 'CCLC'
            daysVector = [commonYearVec, commonYearVec, leapYearVec, commonYearVec];
        case 'CLCC'
            daysVector = [commonYearVec, leapYearVec, commonYearVec, commonYearVec];
        case 'LCCC'
            daysVector = [leapYearVec, commonYearVec, commonYearVec, commonYearVec];
        case 'CCCC'
            daysVector = [commonYearVec, commonYearVec, commonYearVec, commonYearVec];
        otherwise
            error('Invalid type!');
    end
end
